@@ -100,6 +100,15 @@ def create_app(config_settings=MagicSettings()):
     return g.app
 
 
+from fastapi.routing import APIRoute
+
+
+def use_route_names_as_operation_ids(app: FastAPI) -> None:
+    for route in app.routes:
+        if isinstance(route, APIRoute):
+            route.operation_id = route.name
+
+
 def create_handler(app):
     def handler(event, context):
         """Handler to give to lambda... which wraps FastAPI"""
